package com.szr.zdryztpg.config;

import com.alibaba.fastjson.JSONObject;
import com.szr.common.model.BaseResponse;
import com.szr.common.model.dto.UserInfoDTO;
import com.szr.common.utils.UserThreadLocal;
import com.szr.zdryztpg.service.AdminService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestAttributes;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.PrintWriter;

/**
 * @author yangyang
 * @desc 登录信息鉴权
 * @date 2022/1/5 9:58
 */
@Component
@Slf4j
public class UserInfoInterceptor implements HandlerInterceptor {

    @Autowired
    @Lazy
    private AdminService adminService;

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response,
                             Object handler) throws Exception {
        log.info(request.getRequestURI() + "-" +request.getRequestURL());
        String userId = request.getHeader("userId");
        log.info("获取到用户信息 userId : {}", userId);
        if(StringUtils.isEmpty(userId)){
            response.setCharacterEncoding("UTF-8");
            response.setContentType("application/json; charset=utf-8");
            //解决 return false  跨域问题---两者缺一不可，*号表示匹配所有。
            response.setHeader("Access-Control-Allow-Origin", "*");
            response.setHeader("Access-Control-Allow-Headers", "*");
            PrintWriter writer = response.getWriter();
            writer.print(buildJson());
            return false;
        }
        BaseResponse<UserInfoDTO> userInfoBase = adminService.getUserInfoDTOByUserId(userId);
        if(userInfoBase!=null && userInfoBase.getCode() == 200) {
            UserInfoDTO userInfoDTO = userInfoBase.getObj();
            UserThreadLocal.put(userInfoDTO);
            UserInheritableThreadLocal.remove();
            UserInheritableThreadLocal.put(userInfoDTO);
            RequestContextHolder.currentRequestAttributes().setAttribute("userId", userId, RequestAttributes.SCOPE_REQUEST);
        } else {
            response.setCharacterEncoding("UTF-8");
            response.setContentType("application/json; charset=utf-8");
            //解决 return false  跨域问题---两者缺一不可，*号表示匹配所有。
            response.setHeader("Access-Control-Allow-Origin", "*");
            response.setHeader("Access-Control-Allow-Headers", "*");
            PrintWriter writer = response.getWriter();
            writer.print("未获取到用户信息");
        }
        return true;
    }

    private String buildJson() {
        JSONObject jsonObject = new JSONObject();
        StringBuilder url = new StringBuilder();
        jsonObject.put("code",201);
        jsonObject.put("message","未登录");
        return jsonObject.toJSONString();
    }



}
