package com.szr.zdryztpg.config;

import com.google.gson.Gson;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.*;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.lang.reflect.Method;

@Aspect
@Component
@Slf4j
public class WebLoggerAspect {
 
    @Pointcut("@annotation(com.szr.zdryztpg.config.WebLogger)")
    public void log() {}
 
    @Around("log()")
    public Object doAround(ProceedingJoinPoint joinPoint) throws Throwable {
        long startTime=System.currentTimeMillis();
 
        Object result=joinPoint.proceed();
        log.info("Response："+new Gson().toJson(result));
        log.info("耗时："+(System.currentTimeMillis()-startTime));
 
        return result;
    }

    @Before("log()")
    public void doBefore(JoinPoint joinPoint) {
        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = attributes.getRequest();
        log.info("==================Start=================");
        log.info("URL：" + request.getRequestURL().toString());
        log.info("Description：" + getLogValue(joinPoint));
        log.info("Method：" + request.getMethod().toString());
        //打印controller全路径及method
        log.info("Class Method：" + joinPoint.getSignature().getDeclaringTypeName() + "," + joinPoint.getSignature().getName());
        log.info("客户端IP：" + request.getRemoteAddr());
        log.info("请求参数：" + new Gson().toJson(joinPoint.getArgs()));
 
    }
 
    private String getLogValue(JoinPoint joinPoint) {
        MethodSignature methodSignature = (MethodSignature) joinPoint.getSignature();
        Method method = methodSignature.getMethod();
        WebLogger webLogger = method.getAnnotation(WebLogger.class);
        return webLogger.value();
    }
 
    @After("log()")
    public void doAfter() {
        log.info("==================End=================");
    }
}