package com.szr.zdryztpg.service;

import com.szr.common.model.BaseResponse;
import com.szr.common.model.RootResource;
import com.szr.common.model.dto.UserInfoDTO;
import com.szr.common.model.params.GetScenesPermissionParams;
import com.szr.common.model.params.UpdatePasswordParams;
import com.szr.common.model.params.UpdateSelfInfoParams;
import com.szr.zdryztpg.config.FeignConfiguration;
import com.szr.zdryztpg.model.Department;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @ClassName: AdminService
 * @Description: 后台管理
 * @Date: 2023/02/24 13:51
 * @Version: v1.0
 */
@FeignClient(value="admin-service", configuration = FeignConfiguration.class, url = "${feign.admin.url}")
public interface AdminService {


    /**
     * 部门下用户列表
     *
     * @param
     * @return
     */
    @PostMapping(value = "/userManage/selectDepartmentUserList")
    BaseResponse<List<UserInfoDTO>> selectDepartmentUserList();

    /**
     * 场景-获取权限
     *
     * @param getScenesPermissionParams
     * @return
     */
    @PostMapping(value = "/userManage/getPrivilege")
    BaseResponse<RootResource> getPrivilege(@RequestBody GetScenesPermissionParams getScenesPermissionParams);

    /**
     * 个人更新用户信息
     *
     * @param updateSelfInfoParams
     * @return
     */
    @PutMapping(value = "/userManage/updateUserSelf")
    BaseResponse updateUserSelf(@RequestBody UpdateSelfInfoParams updateSelfInfoParams);

    /**
     * 修改密码
     *
     * @param updatePasswordParams
     * @return
     */
    @PostMapping(value = "/userManage/updatePassword")
    BaseResponse updatePassword(@RequestBody UpdatePasswordParams updatePasswordParams);

    /**
     * 根据用户编号查询用户信息
     *
     * @param userId
     * @return
     */
    @GetMapping(value = "/userManage/getUserInfoDTOByUserId")
    BaseResponse<UserInfoDTO> getUserInfoDTOByUserId(@RequestParam(name = "userId") String userId);


    @GetMapping(value = "/department/getChildDepartmentByDepartmentId")
    BaseResponse<List<Department>> getChildDepartmentByDepartmentId(@RequestParam(name = "userId") String userId, @RequestParam(name = "departmentId") String departmentId, @RequestParam(name = "departmentLevel") int departmentLevel);

    @PostMapping(value = "/userManage/selectDepartmentForUserManage")
    BaseResponse<List<Department>> selectDepartmentForUserManage();
}