package com.szr.zdryztpg.service;

import com.szr.common.model.BaseResponse;
import com.szr.common.model.dto.*;
import com.szr.zdryztpg.config.FeignConfiguration;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * @ClassName: RobotService
 * @Description: 机器人服务
 * @Author: 王运杰
 * @Date: 2023/02/24 13:51
 * @Version: v1.0
 */
@FeignClient(value="robot-run-service" ,configuration = FeignConfiguration.class, url = "${feign.robot.url}")
public interface RobotService {


    /**
     * 选择并执行数字人
     *
     * @param
     * @return
     */
    @PostMapping(value = "/robot/selectAndRun")
    BaseResponse<Boolean> selectAndRun(@RequestBody RobotSelectDTO params);


    /**
     * 新增机器人执行明细
     *
     * @param
     * @return
     */
    @PostMapping(value = "/robot/insertExecuteDetail")
    BaseResponse<Boolean> insertExecuteDetail(@RequestBody RobotExecuteDetailDTO params);

    /**
     * 新增播报信息
     *
     * @param
     * @return
     */
    @PostMapping(value = "/voice/saveInvoiceInfo")
    BaseResponse<Boolean> saveInvoiceInfo(@RequestBody VoiceSaveReqDTO params);

    /**
     * 查询播报信息
     *
     * @param
     * @return
     */
    @PostMapping(value = "/voice/queryInvoiceInfo")
    BaseResponse<VoiceSaveRspDTO> queryInvoiceInfo(@RequestBody VoiceQueryReqDTO params);


    @GetMapping("/robot/updateRobotRunningState")
    BaseResponse<Boolean> updateRobotRunningState(@RequestParam("robotId") String robotId);
}